@@ -17,12 +17,7 @@ has migrations      => sub {
   return $migrations;
 };
 has options => sub {
-  {
-    AutoCommit          => 1,
-    AutoInactiveDestroy => 1,
-    PrintError          => 0,
-    RaiseError          => 1
-  };
+  {AutoCommit => 1, AutoInactiveDestroy => 1, PrintError => 0, RaiseError => 1};
 };
 has [qw(password username)] => '';
 has pubsub => sub {
@@ -31,7 +26,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.08';
+our $VERSION = '2.09';
 
 sub db {
   my $self = shift;
